@@ -18,10 +18,10 @@
 
 #include "commandstest.h"
 
-#include <QtTest/QTest>
+#include <QTest>
 
 #include "analyzer.h"
-#include "config-analitza.h"
+#include <config-analitza.h>
 
 using Analitza::Expression;
 
