@@ -32,8 +32,6 @@ class QItemSelectionModel;
 
 namespace Analitza
 {
-class Surface;
-class PlotItem;
 
 /**
  * \class PlotsView3DES
@@ -51,7 +49,7 @@ class ANALITZAWIDGETS_EXPORT PlotsView3DES : public QOpenGLWidget, public Plotte
     Q_OBJECT
 
 public:
-    PlotsView3DES(QWidget* parent = 0);
+    explicit PlotsView3DES(QWidget* parent = nullptr);
     virtual ~PlotsView3DES();
 
     void setSelectionModel(QItemSelectionModel* selection);
